# coding: utf-8

from sqlalchemy import (
    MetaData, String, Table, Column, Integer, Text, UnicodeText, Unicode)
from migrate.changeset.constraint import ForeignKeyConstraint


LEVEL_INCRIMENTAL = 0
BAREOS = 0


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    backup_templates = Table(
        'backup_templates', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('domain_id', String(256), nullable=False),
        Column('name', Unicode(100), nullable=False),
        Column('description', UnicodeText, nullable=False),
        Column('level', Integer, nullable=False, default=LEVEL_INCRIMENTAL),
        Column('job_defs', String(256)),
        Column('file_set', String(256)),
        Column('schedule', String(256)),
        mysql_charset='utf8'
    )

    server_backup_templates = Table(
        'server_backup_templates', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('instance_id', String(36), nullable=False),
        Column('backup_templates_id', Integer, nullable=False),
        mysql_charset='utf8'
    )

    backup_systems = Table(
        'backup_systems', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('domain_id', String(256), nullable=False),
        Column('hostname', Unicode(50), nullable=False),
        Column('password', Unicode(50), nullable=False),
        Column('private_key', Text, nullable=False),
        Column('backup_system', Integer, nullable=False, default=BAREOS),
        mysql_charset='utf8'
    )

    backup_templates.create()
    server_backup_templates.create()
    backup_systems.create()

    ForeignKeyConstraint(
        columns=[server_backup_templates.c.backup_templates_id],
        refcolumns=[backup_templates.c.id],
        ondelete='CASCADE', onupdate='CASCADE'
    ).create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)

    backup_templates = Table('backup_templates', meta, autoload=True)
    server_backup_templates = Table(
        'server_backup_templates', meta, autoload=True
    )
    backup_systems = Table('host_class', meta, autoload=True)

    ForeignKeyConstraint(
        columns=[server_backup_templates.c.backup_templates_id],
        refcolumns=[backup_templates.c.id],
        ondelete='CASCADE', onupdate='CASCADE'
    ).drop()

    backup_templates.drop()
    backup_systems.drop()
    server_backup_templates.drop()
