# coding: utf-8

from sqlalchemy import (
    MetaData, Table, Column, String, DateTime, Integer, Unicode, UnicodeText,
    Text)


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    zabbix_table = Table(
        'shadow_tnx_zabbix', meta,
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('id', Integer, primary_key=True),

        Column('zabbix_user_login', String(255), nullable=False, default=''),
        Column('zabbix_user_password', String(128), nullable=False,
               default=''),
        Column('project_id', String(64), nullable=False),
    )
    zabbix_table.create()

    backup_templates = Table(
        'shadow_backup_templates', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('domain_id', String(256), nullable=False),
        Column('name', Unicode(100), nullable=False),
        Column('description', UnicodeText, nullable=False),
        Column('level', Integer, nullable=False, default=0),
        Column('job_defs', String(256)),
        Column('file_set', String(256)),
        Column('schedule', String(256)),
        mysql_charset='utf8'
    )

    server_backup_templates = Table(
        'shadow_server_backup_templates', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('instance_id', String(36), nullable=False),
        Column('backup_templates_id', Integer, nullable=False),
        mysql_charset='utf8'
    )

    backup_systems = Table(
        'shadow_backup_systems', meta,
        Column('id', Integer, primary_key=True, nullable=False),
        Column('created_at', DateTime),
        Column('updated_at', DateTime),
        Column('deleted_at', DateTime),
        Column('deleted', Integer),
        Column('domain_id', String(256), nullable=False),
        Column('hostname', Unicode(50), nullable=False),
        Column('password', Unicode(50), nullable=False),
        Column('private_key', Text, nullable=False),
        Column('backup_system', Integer, nullable=False, default=0),
        mysql_charset='utf8'
    )

    backup_templates.create()
    server_backup_templates.create()
    backup_systems.create()


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tables = ('tnx_zabbix', 'backup_templates', 'server_backup_templates',
              'backup_systems', )
    for table_name in tables:
        table = Table('shadow_' + table_name, meta)
        table.drop()
